
.. vim: foldmarker=[[[,]]]:foldmethod=marker
.. Generated by the scripts contained in https://github.com/debops/docs/tree/master/docs/includes/global.rst
.. This file is possible copied to multiple git repositories.

.. Ansible core [[[

.. _Ansible: https://www.ansible.com/
.. _Ansible Galaxy: https://galaxy.ansible.com/

.. ]]]

.. Ansible modules [[[
.. This section was generated by: https://github.com/debops/docs/blob/master/docs/docs/bin/gen_ansible_modules_rst_defs

.. _Ansible a10_server module: https://docs.ansible.com/ansible/a10_server_module.html
.. _Ansible a10_service_group module: https://docs.ansible.com/ansible/a10_service_group_module.html
.. _Ansible a10_virtual_server module: https://docs.ansible.com/ansible/a10_virtual_server_module.html
.. _Ansible acl module: https://docs.ansible.com/ansible/acl_module.html
.. _Ansible add_host module: https://docs.ansible.com/ansible/add_host_module.html
.. _Ansible airbrake_deployment module: https://docs.ansible.com/ansible/airbrake_deployment_module.html
.. _Ansible alternatives module: https://docs.ansible.com/ansible/alternatives_module.html
.. _Ansible apache2_module module: https://docs.ansible.com/ansible/apache2_module_module.html
.. _Ansible apk module: https://docs.ansible.com/ansible/apk_module.html
.. _Ansible apt module: https://docs.ansible.com/ansible/apt_module.html
.. _Ansible apt_key module: https://docs.ansible.com/ansible/apt_key_module.html
.. _Ansible apt_repository module: https://docs.ansible.com/ansible/apt_repository_module.html
.. _Ansible apt_rpm module: https://docs.ansible.com/ansible/apt_rpm_module.html
.. _Ansible assemble module: https://docs.ansible.com/ansible/assemble_module.html
.. _Ansible assert module: https://docs.ansible.com/ansible/assert_module.html
.. _Ansible async_status module: https://docs.ansible.com/ansible/async_status_module.html
.. _Ansible at module: https://docs.ansible.com/ansible/at_module.html
.. _Ansible authorized_key module: https://docs.ansible.com/ansible/authorized_key_module.html
.. _Ansible aws_mfa_devices module: https://docs.ansible.com/ansible/aws_mfa_devices_module.html
.. _Ansible azure module: https://docs.ansible.com/ansible/azure_module.html
.. _Ansible azure_deployment module: https://docs.ansible.com/ansible/azure_deployment_module.html
.. _Ansible azure_rm_deployment module: https://docs.ansible.com/ansible/azure_rm_deployment_module.html
.. _Ansible azure_rm_networkinterface module: https://docs.ansible.com/ansible/azure_rm_networkinterface_module.html
.. _Ansible azure_rm_networkinterface_facts module: https://docs.ansible.com/ansible/azure_rm_networkinterface_facts_module.html
.. _Ansible azure_rm_publicipaddress module: https://docs.ansible.com/ansible/azure_rm_publicipaddress_module.html
.. _Ansible azure_rm_publicipaddress_facts module: https://docs.ansible.com/ansible/azure_rm_publicipaddress_facts_module.html
.. _Ansible azure_rm_resourcegroup module: https://docs.ansible.com/ansible/azure_rm_resourcegroup_module.html
.. _Ansible azure_rm_resourcegroup_facts module: https://docs.ansible.com/ansible/azure_rm_resourcegroup_facts_module.html
.. _Ansible azure_rm_securitygroup module: https://docs.ansible.com/ansible/azure_rm_securitygroup_module.html
.. _Ansible azure_rm_securitygroup_facts module: https://docs.ansible.com/ansible/azure_rm_securitygroup_facts_module.html
.. _Ansible azure_rm_storageaccount module: https://docs.ansible.com/ansible/azure_rm_storageaccount_module.html
.. _Ansible azure_rm_storageaccount_facts module: https://docs.ansible.com/ansible/azure_rm_storageaccount_facts_module.html
.. _Ansible azure_rm_storageblob module: https://docs.ansible.com/ansible/azure_rm_storageblob_module.html
.. _Ansible azure_rm_subnet module: https://docs.ansible.com/ansible/azure_rm_subnet_module.html
.. _Ansible azure_rm_virtualmachine module: https://docs.ansible.com/ansible/azure_rm_virtualmachine_module.html
.. _Ansible azure_rm_virtualmachineimage_facts module: https://docs.ansible.com/ansible/azure_rm_virtualmachineimage_facts_module.html
.. _Ansible azure_rm_virtualnetwork module: https://docs.ansible.com/ansible/azure_rm_virtualnetwork_module.html
.. _Ansible azure_rm_virtualnetwork_facts module: https://docs.ansible.com/ansible/azure_rm_virtualnetwork_facts_module.html
.. _Ansible bigip_facts module: https://docs.ansible.com/ansible/bigip_facts_module.html
.. _Ansible bigip_gtm_virtual_server module: https://docs.ansible.com/ansible/bigip_gtm_virtual_server_module.html
.. _Ansible bigip_gtm_wide_ip module: https://docs.ansible.com/ansible/bigip_gtm_wide_ip_module.html
.. _Ansible bigip_monitor_http module: https://docs.ansible.com/ansible/bigip_monitor_http_module.html
.. _Ansible bigip_monitor_tcp module: https://docs.ansible.com/ansible/bigip_monitor_tcp_module.html
.. _Ansible bigip_node module: https://docs.ansible.com/ansible/bigip_node_module.html
.. _Ansible bigip_pool module: https://docs.ansible.com/ansible/bigip_pool_module.html
.. _Ansible bigip_pool_member module: https://docs.ansible.com/ansible/bigip_pool_member_module.html
.. _Ansible bigip_virtual_server module: https://docs.ansible.com/ansible/bigip_virtual_server_module.html
.. _Ansible bigpanda module: https://docs.ansible.com/ansible/bigpanda_module.html
.. _Ansible blockinfile module: https://docs.ansible.com/ansible/blockinfile_module.html
.. _Ansible boundary_meter module: https://docs.ansible.com/ansible/boundary_meter_module.html
.. _Ansible bower module: https://docs.ansible.com/ansible/bower_module.html
.. _Ansible bundler module: https://docs.ansible.com/ansible/bundler_module.html
.. _Ansible bzr module: https://docs.ansible.com/ansible/bzr_module.html
.. _Ansible campfire module: https://docs.ansible.com/ansible/campfire_module.html
.. _Ansible capabilities module: https://docs.ansible.com/ansible/capabilities_module.html
.. _Ansible circonus_annotation module: https://docs.ansible.com/ansible/circonus_annotation_module.html
.. _Ansible cl_bond module: https://docs.ansible.com/ansible/cl_bond_module.html
.. _Ansible cl_bridge module: https://docs.ansible.com/ansible/cl_bridge_module.html
.. _Ansible cl_img_install module: https://docs.ansible.com/ansible/cl_img_install_module.html
.. _Ansible cl_interface module: https://docs.ansible.com/ansible/cl_interface_module.html
.. _Ansible cl_interface_policy module: https://docs.ansible.com/ansible/cl_interface_policy_module.html
.. _Ansible cl_license module: https://docs.ansible.com/ansible/cl_license_module.html
.. _Ansible cl_ports module: https://docs.ansible.com/ansible/cl_ports_module.html
.. _Ansible clc_aa_policy module: https://docs.ansible.com/ansible/clc_aa_policy_module.html
.. _Ansible clc_alert_policy module: https://docs.ansible.com/ansible/clc_alert_policy_module.html
.. _Ansible clc_blueprint_package module: https://docs.ansible.com/ansible/clc_blueprint_package_module.html
.. _Ansible clc_firewall_policy module: https://docs.ansible.com/ansible/clc_firewall_policy_module.html
.. _Ansible clc_group module: https://docs.ansible.com/ansible/clc_group_module.html
.. _Ansible clc_loadbalancer module: https://docs.ansible.com/ansible/clc_loadbalancer_module.html
.. _Ansible clc_modify_server module: https://docs.ansible.com/ansible/clc_modify_server_module.html
.. _Ansible clc_publicip module: https://docs.ansible.com/ansible/clc_publicip_module.html
.. _Ansible clc_server module: https://docs.ansible.com/ansible/clc_server_module.html
.. _Ansible clc_server_snapshot module: https://docs.ansible.com/ansible/clc_server_snapshot_module.html
.. _Ansible cloudflare_dns module: https://docs.ansible.com/ansible/cloudflare_dns_module.html
.. _Ansible cloudformation module: https://docs.ansible.com/ansible/cloudformation_module.html
.. _Ansible cloudtrail module: https://docs.ansible.com/ansible/cloudtrail_module.html
.. _Ansible command module: https://docs.ansible.com/ansible/command_module.html
.. _Ansible composer module: https://docs.ansible.com/ansible/composer_module.html
.. _Ansible consul module: https://docs.ansible.com/ansible/consul_module.html
.. _Ansible consul_acl module: https://docs.ansible.com/ansible/consul_acl_module.html
.. _Ansible consul_kv module: https://docs.ansible.com/ansible/consul_kv_module.html
.. _Ansible consul_session module: https://docs.ansible.com/ansible/consul_session_module.html
.. _Ansible copy module: https://docs.ansible.com/ansible/copy_module.html
.. _Ansible cpanm module: https://docs.ansible.com/ansible/cpanm_module.html
.. _Ansible cron module: https://docs.ansible.com/ansible/cron_module.html
.. _Ansible cronvar module: https://docs.ansible.com/ansible/cronvar_module.html
.. _Ansible crypttab module: https://docs.ansible.com/ansible/crypttab_module.html
.. _Ansible cs_account module: https://docs.ansible.com/ansible/cs_account_module.html
.. _Ansible cs_affinitygroup module: https://docs.ansible.com/ansible/cs_affinitygroup_module.html
.. _Ansible cs_cluster module: https://docs.ansible.com/ansible/cs_cluster_module.html
.. _Ansible cs_configuration module: https://docs.ansible.com/ansible/cs_configuration_module.html
.. _Ansible cs_domain module: https://docs.ansible.com/ansible/cs_domain_module.html
.. _Ansible cs_facts module: https://docs.ansible.com/ansible/cs_facts_module.html
.. _Ansible cs_firewall module: https://docs.ansible.com/ansible/cs_firewall_module.html
.. _Ansible cs_instance module: https://docs.ansible.com/ansible/cs_instance_module.html
.. _Ansible cs_instance_facts module: https://docs.ansible.com/ansible/cs_instance_facts_module.html
.. _Ansible cs_instancegroup module: https://docs.ansible.com/ansible/cs_instancegroup_module.html
.. _Ansible cs_ip_address module: https://docs.ansible.com/ansible/cs_ip_address_module.html
.. _Ansible cs_iso module: https://docs.ansible.com/ansible/cs_iso_module.html
.. _Ansible cs_loadbalancer_rule module: https://docs.ansible.com/ansible/cs_loadbalancer_rule_module.html
.. _Ansible cs_loadbalancer_rule_member module: https://docs.ansible.com/ansible/cs_loadbalancer_rule_member_module.html
.. _Ansible cs_network module: https://docs.ansible.com/ansible/cs_network_module.html
.. _Ansible cs_pod module: https://docs.ansible.com/ansible/cs_pod_module.html
.. _Ansible cs_portforward module: https://docs.ansible.com/ansible/cs_portforward_module.html
.. _Ansible cs_project module: https://docs.ansible.com/ansible/cs_project_module.html
.. _Ansible cs_resourcelimit module: https://docs.ansible.com/ansible/cs_resourcelimit_module.html
.. _Ansible cs_router module: https://docs.ansible.com/ansible/cs_router_module.html
.. _Ansible cs_securitygroup module: https://docs.ansible.com/ansible/cs_securitygroup_module.html
.. _Ansible cs_securitygroup_rule module: https://docs.ansible.com/ansible/cs_securitygroup_rule_module.html
.. _Ansible cs_snapshot_policy module: https://docs.ansible.com/ansible/cs_snapshot_policy_module.html
.. _Ansible cs_sshkeypair module: https://docs.ansible.com/ansible/cs_sshkeypair_module.html
.. _Ansible cs_staticnat module: https://docs.ansible.com/ansible/cs_staticnat_module.html
.. _Ansible cs_template module: https://docs.ansible.com/ansible/cs_template_module.html
.. _Ansible cs_user module: https://docs.ansible.com/ansible/cs_user_module.html
.. _Ansible cs_vmsnapshot module: https://docs.ansible.com/ansible/cs_vmsnapshot_module.html
.. _Ansible cs_volume module: https://docs.ansible.com/ansible/cs_volume_module.html
.. _Ansible cs_zone module: https://docs.ansible.com/ansible/cs_zone_module.html
.. _Ansible cs_zone_facts module: https://docs.ansible.com/ansible/cs_zone_facts_module.html
.. _Ansible datadog_event module: https://docs.ansible.com/ansible/datadog_event_module.html
.. _Ansible datadog_monitor module: https://docs.ansible.com/ansible/datadog_monitor_module.html
.. _Ansible debconf module: https://docs.ansible.com/ansible/debconf_module.html
.. _Ansible debug module: https://docs.ansible.com/ansible/debug_module.html
.. _Ansible deploy_helper module: https://docs.ansible.com/ansible/deploy_helper_module.html
.. _Ansible digital_ocean module: https://docs.ansible.com/ansible/digital_ocean_module.html
.. _Ansible digital_ocean_domain module: https://docs.ansible.com/ansible/digital_ocean_domain_module.html
.. _Ansible digital_ocean_sshkey module: https://docs.ansible.com/ansible/digital_ocean_sshkey_module.html
.. _Ansible django_manage module: https://docs.ansible.com/ansible/django_manage_module.html
.. _Ansible dnf module: https://docs.ansible.com/ansible/dnf_module.html
.. _Ansible dnsimple module: https://docs.ansible.com/ansible/dnsimple_module.html
.. _Ansible dnsmadeeasy module: https://docs.ansible.com/ansible/dnsmadeeasy_module.html
.. _Ansible docker module: https://docs.ansible.com/ansible/docker_module.html
.. _Ansible docker_container module: https://docs.ansible.com/ansible/docker_container_module.html
.. _Ansible docker_image module: https://docs.ansible.com/ansible/docker_image_module.html
.. _Ansible docker_image_facts module: https://docs.ansible.com/ansible/docker_image_facts_module.html
.. _Ansible docker_login module: https://docs.ansible.com/ansible/docker_login_module.html
.. _Ansible docker_service module: https://docs.ansible.com/ansible/docker_service_module.html
.. _Ansible dpkg_selections module: https://docs.ansible.com/ansible/dpkg_selections_module.html
.. _Ansible dynamodb_table module: https://docs.ansible.com/ansible/dynamodb_table_module.html
.. _Ansible easy_install module: https://docs.ansible.com/ansible/easy_install_module.html
.. _Ansible ec2 module: https://docs.ansible.com/ansible/ec2_module.html
.. _Ansible ec2_ami module: https://docs.ansible.com/ansible/ec2_ami_module.html
.. _Ansible ec2_ami_copy module: https://docs.ansible.com/ansible/ec2_ami_copy_module.html
.. _Ansible ec2_ami_find module: https://docs.ansible.com/ansible/ec2_ami_find_module.html
.. _Ansible ec2_ami_search module: https://docs.ansible.com/ansible/ec2_ami_search_module.html
.. _Ansible ec2_asg module: https://docs.ansible.com/ansible/ec2_asg_module.html
.. _Ansible ec2_customer_gateway module: https://docs.ansible.com/ansible/ec2_customer_gateway_module.html
.. _Ansible ec2_eip module: https://docs.ansible.com/ansible/ec2_eip_module.html
.. _Ansible ec2_elb module: https://docs.ansible.com/ansible/ec2_elb_module.html
.. _Ansible ec2_elb_facts module: https://docs.ansible.com/ansible/ec2_elb_facts_module.html
.. _Ansible ec2_elb_lb module: https://docs.ansible.com/ansible/ec2_elb_lb_module.html
.. _Ansible ec2_eni module: https://docs.ansible.com/ansible/ec2_eni_module.html
.. _Ansible ec2_eni_facts module: https://docs.ansible.com/ansible/ec2_eni_facts_module.html
.. _Ansible ec2_facts module: https://docs.ansible.com/ansible/ec2_facts_module.html
.. _Ansible ec2_group module: https://docs.ansible.com/ansible/ec2_group_module.html
.. _Ansible ec2_key module: https://docs.ansible.com/ansible/ec2_key_module.html
.. _Ansible ec2_lc module: https://docs.ansible.com/ansible/ec2_lc_module.html
.. _Ansible ec2_metric_alarm module: https://docs.ansible.com/ansible/ec2_metric_alarm_module.html
.. _Ansible ec2_remote_facts module: https://docs.ansible.com/ansible/ec2_remote_facts_module.html
.. _Ansible ec2_scaling_policy module: https://docs.ansible.com/ansible/ec2_scaling_policy_module.html
.. _Ansible ec2_snapshot module: https://docs.ansible.com/ansible/ec2_snapshot_module.html
.. _Ansible ec2_snapshot_facts module: https://docs.ansible.com/ansible/ec2_snapshot_facts_module.html
.. _Ansible ec2_tag module: https://docs.ansible.com/ansible/ec2_tag_module.html
.. _Ansible ec2_vol module: https://docs.ansible.com/ansible/ec2_vol_module.html
.. _Ansible ec2_vol_facts module: https://docs.ansible.com/ansible/ec2_vol_facts_module.html
.. _Ansible ec2_vpc module: https://docs.ansible.com/ansible/ec2_vpc_module.html
.. _Ansible ec2_vpc_dhcp_options module: https://docs.ansible.com/ansible/ec2_vpc_dhcp_options_module.html
.. _Ansible ec2_vpc_igw module: https://docs.ansible.com/ansible/ec2_vpc_igw_module.html
.. _Ansible ec2_vpc_nacl module: https://docs.ansible.com/ansible/ec2_vpc_nacl_module.html
.. _Ansible ec2_vpc_net module: https://docs.ansible.com/ansible/ec2_vpc_net_module.html
.. _Ansible ec2_vpc_net_facts module: https://docs.ansible.com/ansible/ec2_vpc_net_facts_module.html
.. _Ansible ec2_vpc_peer module: https://docs.ansible.com/ansible/ec2_vpc_peer_module.html
.. _Ansible ec2_vpc_route_table module: https://docs.ansible.com/ansible/ec2_vpc_route_table_module.html
.. _Ansible ec2_vpc_route_table_facts module: https://docs.ansible.com/ansible/ec2_vpc_route_table_facts_module.html
.. _Ansible ec2_vpc_subnet module: https://docs.ansible.com/ansible/ec2_vpc_subnet_module.html
.. _Ansible ec2_vpc_subnet_facts module: https://docs.ansible.com/ansible/ec2_vpc_subnet_facts_module.html
.. _Ansible ec2_win_password module: https://docs.ansible.com/ansible/ec2_win_password_module.html
.. _Ansible ecs_cluster module: https://docs.ansible.com/ansible/ecs_cluster_module.html
.. _Ansible ecs_service module: https://docs.ansible.com/ansible/ecs_service_module.html
.. _Ansible ecs_service_facts module: https://docs.ansible.com/ansible/ecs_service_facts_module.html
.. _Ansible ecs_task module: https://docs.ansible.com/ansible/ecs_task_module.html
.. _Ansible ecs_taskdefinition module: https://docs.ansible.com/ansible/ecs_taskdefinition_module.html
.. _Ansible ejabberd_user module: https://docs.ansible.com/ansible/ejabberd_user_module.html
.. _Ansible elasticache module: https://docs.ansible.com/ansible/elasticache_module.html
.. _Ansible elasticache_subnet_group module: https://docs.ansible.com/ansible/elasticache_subnet_group_module.html
.. _Ansible elasticsearch_plugin module: https://docs.ansible.com/ansible/elasticsearch_plugin_module.html
.. _Ansible eos_command module: https://docs.ansible.com/ansible/eos_command_module.html
.. _Ansible eos_config module: https://docs.ansible.com/ansible/eos_config_module.html
.. _Ansible eos_eapi module: https://docs.ansible.com/ansible/eos_eapi_module.html
.. _Ansible eos_template module: https://docs.ansible.com/ansible/eos_template_module.html
.. _Ansible expect module: https://docs.ansible.com/ansible/expect_module.html
.. _Ansible facter module: https://docs.ansible.com/ansible/facter_module.html
.. _Ansible fail module: https://docs.ansible.com/ansible/fail_module.html
.. _Ansible fetch module: https://docs.ansible.com/ansible/fetch_module.html
.. _Ansible file module: https://docs.ansible.com/ansible/file_module.html
.. _Ansible filesystem module: https://docs.ansible.com/ansible/filesystem_module.html
.. _Ansible find module: https://docs.ansible.com/ansible/find_module.html
.. _Ansible firewalld module: https://docs.ansible.com/ansible/firewalld_module.html
.. _Ansible flowdock module: https://docs.ansible.com/ansible/flowdock_module.html
.. _Ansible gc_storage module: https://docs.ansible.com/ansible/gc_storage_module.html
.. _Ansible gce module: https://docs.ansible.com/ansible/gce_module.html
.. _Ansible gce_img module: https://docs.ansible.com/ansible/gce_img_module.html
.. _Ansible gce_lb module: https://docs.ansible.com/ansible/gce_lb_module.html
.. _Ansible gce_net module: https://docs.ansible.com/ansible/gce_net_module.html
.. _Ansible gce_pd module: https://docs.ansible.com/ansible/gce_pd_module.html
.. _Ansible gce_tag module: https://docs.ansible.com/ansible/gce_tag_module.html
.. _Ansible gem module: https://docs.ansible.com/ansible/gem_module.html
.. _Ansible get_url module: https://docs.ansible.com/ansible/get_url_module.html
.. _Ansible getent module: https://docs.ansible.com/ansible/getent_module.html
.. _Ansible git module: https://docs.ansible.com/ansible/git_module.html
.. _Ansible git_config module: https://docs.ansible.com/ansible/git_config_module.html
.. _Ansible github_hooks module: https://docs.ansible.com/ansible/github_hooks_module.html
.. _Ansible github_release module: https://docs.ansible.com/ansible/github_release_module.html
.. _Ansible gitlab_group module: https://docs.ansible.com/ansible/gitlab_group_module.html
.. _Ansible gitlab_project module: https://docs.ansible.com/ansible/gitlab_project_module.html
.. _Ansible gitlab_user module: https://docs.ansible.com/ansible/gitlab_user_module.html
.. _Ansible glance_image module: https://docs.ansible.com/ansible/glance_image_module.html
.. _Ansible gluster_volume module: https://docs.ansible.com/ansible/gluster_volume_module.html
.. _Ansible group module: https://docs.ansible.com/ansible/group_module.html
.. _Ansible group_by module: https://docs.ansible.com/ansible/group_by_module.html
.. _Ansible grove module: https://docs.ansible.com/ansible/grove_module.html
.. _Ansible hall module: https://docs.ansible.com/ansible/hall_module.html
.. _Ansible haproxy module: https://docs.ansible.com/ansible/haproxy_module.html
.. _Ansible hg module: https://docs.ansible.com/ansible/hg_module.html
.. _Ansible hipchat module: https://docs.ansible.com/ansible/hipchat_module.html
.. _Ansible homebrew module: https://docs.ansible.com/ansible/homebrew_module.html
.. _Ansible homebrew_cask module: https://docs.ansible.com/ansible/homebrew_cask_module.html
.. _Ansible homebrew_tap module: https://docs.ansible.com/ansible/homebrew_tap_module.html
.. _Ansible honeybadger_deployment module: https://docs.ansible.com/ansible/honeybadger_deployment_module.html
.. _Ansible hostname module: https://docs.ansible.com/ansible/hostname_module.html
.. _Ansible htpasswd module: https://docs.ansible.com/ansible/htpasswd_module.html
.. _Ansible iam module: https://docs.ansible.com/ansible/iam_module.html
.. _Ansible iam_cert module: https://docs.ansible.com/ansible/iam_cert_module.html
.. _Ansible iam_mfa_device_facts module: https://docs.ansible.com/ansible/iam_mfa_device_facts_module.html
.. _Ansible iam_policy module: https://docs.ansible.com/ansible/iam_policy_module.html
.. _Ansible include_vars module: https://docs.ansible.com/ansible/include_vars_module.html
.. _Ansible influxdb_database module: https://docs.ansible.com/ansible/influxdb_database_module.html
.. _Ansible influxdb_retention_policy module: https://docs.ansible.com/ansible/influxdb_retention_policy_module.html
.. _Ansible ini_file module: https://docs.ansible.com/ansible/ini_file_module.html
.. _Ansible ios_command module: https://docs.ansible.com/ansible/ios_command_module.html
.. _Ansible ios_config module: https://docs.ansible.com/ansible/ios_config_module.html
.. _Ansible ios_template module: https://docs.ansible.com/ansible/ios_template_module.html
.. _Ansible iosxr_command module: https://docs.ansible.com/ansible/iosxr_command_module.html
.. _Ansible iosxr_config module: https://docs.ansible.com/ansible/iosxr_config_module.html
.. _Ansible iosxr_template module: https://docs.ansible.com/ansible/iosxr_template_module.html
.. _Ansible ipify_facts module: https://docs.ansible.com/ansible/ipify_facts_module.html
.. _Ansible iptables module: https://docs.ansible.com/ansible/iptables_module.html
.. _Ansible irc module: https://docs.ansible.com/ansible/irc_module.html
.. _Ansible jabber module: https://docs.ansible.com/ansible/jabber_module.html
.. _Ansible jboss module: https://docs.ansible.com/ansible/jboss_module.html
.. _Ansible jira module: https://docs.ansible.com/ansible/jira_module.html
.. _Ansible junos_command module: https://docs.ansible.com/ansible/junos_command_module.html
.. _Ansible junos_config module: https://docs.ansible.com/ansible/junos_config_module.html
.. _Ansible junos_facts module: https://docs.ansible.com/ansible/junos_facts_module.html
.. _Ansible junos_netconf module: https://docs.ansible.com/ansible/junos_netconf_module.html
.. _Ansible junos_package module: https://docs.ansible.com/ansible/junos_package_module.html
.. _Ansible junos_template module: https://docs.ansible.com/ansible/junos_template_module.html
.. _Ansible kernel_blacklist module: https://docs.ansible.com/ansible/kernel_blacklist_module.html
.. _Ansible keystone_user module: https://docs.ansible.com/ansible/keystone_user_module.html
.. _Ansible known_hosts module: https://docs.ansible.com/ansible/known_hosts_module.html
.. _Ansible kubernetes module: https://docs.ansible.com/ansible/kubernetes_module.html
.. _Ansible layman module: https://docs.ansible.com/ansible/layman_module.html
.. _Ansible ldap_attr module: https://docs.ansible.com/ansible/ldap_attr_module.html
.. _Ansible ldap_entry module: https://docs.ansible.com/ansible/ldap_entry_module.html
.. _Ansible letsencrypt module: https://docs.ansible.com/ansible/letsencrypt_module.html
.. _Ansible librato_annotation module: https://docs.ansible.com/ansible/librato_annotation_module.html
.. _Ansible lineinfile module: https://docs.ansible.com/ansible/lineinfile_module.html
.. _Ansible linode module: https://docs.ansible.com/ansible/linode_module.html
.. _Ansible lldp module: https://docs.ansible.com/ansible/lldp_module.html
.. _Ansible locale_gen module: https://docs.ansible.com/ansible/locale_gen_module.html
.. _Ansible logentries module: https://docs.ansible.com/ansible/logentries_module.html
.. _Ansible lvg module: https://docs.ansible.com/ansible/lvg_module.html
.. _Ansible lvol module: https://docs.ansible.com/ansible/lvol_module.html
.. _Ansible lxc_container module: https://docs.ansible.com/ansible/lxc_container_module.html
.. _Ansible macports module: https://docs.ansible.com/ansible/macports_module.html
.. _Ansible mail module: https://docs.ansible.com/ansible/mail_module.html
.. _Ansible make module: https://docs.ansible.com/ansible/make_module.html
.. _Ansible maven_artifact module: https://docs.ansible.com/ansible/maven_artifact_module.html
.. _Ansible modprobe module: https://docs.ansible.com/ansible/modprobe_module.html
.. _Ansible mongodb_parameter module: https://docs.ansible.com/ansible/mongodb_parameter_module.html
.. _Ansible mongodb_user module: https://docs.ansible.com/ansible/mongodb_user_module.html
.. _Ansible monit module: https://docs.ansible.com/ansible/monit_module.html
.. _Ansible mount module: https://docs.ansible.com/ansible/mount_module.html
.. _Ansible mqtt module: https://docs.ansible.com/ansible/mqtt_module.html
.. _Ansible mssql_db module: https://docs.ansible.com/ansible/mssql_db_module.html
.. _Ansible mysql_db module: https://docs.ansible.com/ansible/mysql_db_module.html
.. _Ansible mysql_replication module: https://docs.ansible.com/ansible/mysql_replication_module.html
.. _Ansible mysql_user module: https://docs.ansible.com/ansible/mysql_user_module.html
.. _Ansible mysql_variables module: https://docs.ansible.com/ansible/mysql_variables_module.html
.. _Ansible nagios module: https://docs.ansible.com/ansible/nagios_module.html
.. _Ansible netconf_config module: https://docs.ansible.com/ansible/netconf_config_module.html
.. _Ansible netscaler module: https://docs.ansible.com/ansible/netscaler_module.html
.. _Ansible newrelic_deployment module: https://docs.ansible.com/ansible/newrelic_deployment_module.html
.. _Ansible nexmo module: https://docs.ansible.com/ansible/nexmo_module.html
.. _Ansible nmcli module: https://docs.ansible.com/ansible/nmcli_module.html
.. _Ansible nova_compute module: https://docs.ansible.com/ansible/nova_compute_module.html
.. _Ansible nova_keypair module: https://docs.ansible.com/ansible/nova_keypair_module.html
.. _Ansible npm module: https://docs.ansible.com/ansible/npm_module.html
.. _Ansible nxos_command module: https://docs.ansible.com/ansible/nxos_command_module.html
.. _Ansible nxos_config module: https://docs.ansible.com/ansible/nxos_config_module.html
.. _Ansible nxos_facts module: https://docs.ansible.com/ansible/nxos_facts_module.html
.. _Ansible nxos_feature module: https://docs.ansible.com/ansible/nxos_feature_module.html
.. _Ansible nxos_interface module: https://docs.ansible.com/ansible/nxos_interface_module.html
.. _Ansible nxos_ip_interface module: https://docs.ansible.com/ansible/nxos_ip_interface_module.html
.. _Ansible nxos_nxapi module: https://docs.ansible.com/ansible/nxos_nxapi_module.html
.. _Ansible nxos_ping module: https://docs.ansible.com/ansible/nxos_ping_module.html
.. _Ansible nxos_switchport module: https://docs.ansible.com/ansible/nxos_switchport_module.html
.. _Ansible nxos_template module: https://docs.ansible.com/ansible/nxos_template_module.html
.. _Ansible nxos_vlan module: https://docs.ansible.com/ansible/nxos_vlan_module.html
.. _Ansible nxos_vrf module: https://docs.ansible.com/ansible/nxos_vrf_module.html
.. _Ansible nxos_vrf_interface module: https://docs.ansible.com/ansible/nxos_vrf_interface_module.html
.. _Ansible nxos_vrrp module: https://docs.ansible.com/ansible/nxos_vrrp_module.html
.. _Ansible ohai module: https://docs.ansible.com/ansible/ohai_module.html
.. _Ansible open_iscsi module: https://docs.ansible.com/ansible/open_iscsi_module.html
.. _Ansible openbsd_pkg module: https://docs.ansible.com/ansible/openbsd_pkg_module.html
.. _Ansible openvswitch_bridge module: https://docs.ansible.com/ansible/openvswitch_bridge_module.html
.. _Ansible openvswitch_db module: https://docs.ansible.com/ansible/openvswitch_db_module.html
.. _Ansible openvswitch_port module: https://docs.ansible.com/ansible/openvswitch_port_module.html
.. _Ansible opkg module: https://docs.ansible.com/ansible/opkg_module.html
.. _Ansible ops_command module: https://docs.ansible.com/ansible/ops_command_module.html
.. _Ansible ops_config module: https://docs.ansible.com/ansible/ops_config_module.html
.. _Ansible ops_facts module: https://docs.ansible.com/ansible/ops_facts_module.html
.. _Ansible ops_template module: https://docs.ansible.com/ansible/ops_template_module.html
.. _Ansible os_auth module: https://docs.ansible.com/ansible/os_auth_module.html
.. _Ansible os_client_config module: https://docs.ansible.com/ansible/os_client_config_module.html
.. _Ansible os_flavor_facts module: https://docs.ansible.com/ansible/os_flavor_facts_module.html
.. _Ansible os_floating_ip module: https://docs.ansible.com/ansible/os_floating_ip_module.html
.. _Ansible os_group module: https://docs.ansible.com/ansible/os_group_module.html
.. _Ansible os_image module: https://docs.ansible.com/ansible/os_image_module.html
.. _Ansible os_image_facts module: https://docs.ansible.com/ansible/os_image_facts_module.html
.. _Ansible os_ironic module: https://docs.ansible.com/ansible/os_ironic_module.html
.. _Ansible os_ironic_inspect module: https://docs.ansible.com/ansible/os_ironic_inspect_module.html
.. _Ansible os_ironic_node module: https://docs.ansible.com/ansible/os_ironic_node_module.html
.. _Ansible os_keypair module: https://docs.ansible.com/ansible/os_keypair_module.html
.. _Ansible os_keystone_domain module: https://docs.ansible.com/ansible/os_keystone_domain_module.html
.. _Ansible os_keystone_domain_facts module: https://docs.ansible.com/ansible/os_keystone_domain_facts_module.html
.. _Ansible os_keystone_role module: https://docs.ansible.com/ansible/os_keystone_role_module.html
.. _Ansible os_keystone_service module: https://docs.ansible.com/ansible/os_keystone_service_module.html
.. _Ansible os_network module: https://docs.ansible.com/ansible/os_network_module.html
.. _Ansible os_networks_facts module: https://docs.ansible.com/ansible/os_networks_facts_module.html
.. _Ansible os_nova_flavor module: https://docs.ansible.com/ansible/os_nova_flavor_module.html
.. _Ansible os_object module: https://docs.ansible.com/ansible/os_object_module.html
.. _Ansible os_port module: https://docs.ansible.com/ansible/os_port_module.html
.. _Ansible os_port_facts module: https://docs.ansible.com/ansible/os_port_facts_module.html
.. _Ansible os_project module: https://docs.ansible.com/ansible/os_project_module.html
.. _Ansible os_project_facts module: https://docs.ansible.com/ansible/os_project_facts_module.html
.. _Ansible os_router module: https://docs.ansible.com/ansible/os_router_module.html
.. _Ansible os_security_group module: https://docs.ansible.com/ansible/os_security_group_module.html
.. _Ansible os_security_group_rule module: https://docs.ansible.com/ansible/os_security_group_rule_module.html
.. _Ansible os_server module: https://docs.ansible.com/ansible/os_server_module.html
.. _Ansible os_server_actions module: https://docs.ansible.com/ansible/os_server_actions_module.html
.. _Ansible os_server_facts module: https://docs.ansible.com/ansible/os_server_facts_module.html
.. _Ansible os_server_volume module: https://docs.ansible.com/ansible/os_server_volume_module.html
.. _Ansible os_subnet module: https://docs.ansible.com/ansible/os_subnet_module.html
.. _Ansible os_subnets_facts module: https://docs.ansible.com/ansible/os_subnets_facts_module.html
.. _Ansible os_user module: https://docs.ansible.com/ansible/os_user_module.html
.. _Ansible os_user_facts module: https://docs.ansible.com/ansible/os_user_facts_module.html
.. _Ansible os_user_group module: https://docs.ansible.com/ansible/os_user_group_module.html
.. _Ansible os_user_role module: https://docs.ansible.com/ansible/os_user_role_module.html
.. _Ansible os_volume module: https://docs.ansible.com/ansible/os_volume_module.html
.. _Ansible osx_defaults module: https://docs.ansible.com/ansible/osx_defaults_module.html
.. _Ansible osx_say module: https://docs.ansible.com/ansible/osx_say_module.html
.. _Ansible ovirt module: https://docs.ansible.com/ansible/ovirt_module.html
.. _Ansible package module: https://docs.ansible.com/ansible/package_module.html
.. _Ansible pacman module: https://docs.ansible.com/ansible/pacman_module.html
.. _Ansible pagerduty module: https://docs.ansible.com/ansible/pagerduty_module.html
.. _Ansible pagerduty_alert module: https://docs.ansible.com/ansible/pagerduty_alert_module.html
.. _Ansible pam_limits module: https://docs.ansible.com/ansible/pam_limits_module.html
.. _Ansible patch module: https://docs.ansible.com/ansible/patch_module.html
.. _Ansible pause module: https://docs.ansible.com/ansible/pause_module.html
.. _Ansible pear module: https://docs.ansible.com/ansible/pear_module.html
.. _Ansible ping module: https://docs.ansible.com/ansible/ping_module.html
.. _Ansible pingdom module: https://docs.ansible.com/ansible/pingdom_module.html
.. _Ansible pip module: https://docs.ansible.com/ansible/pip_module.html
.. _Ansible pkg5 module: https://docs.ansible.com/ansible/pkg5_module.html
.. _Ansible pkg5_publisher module: https://docs.ansible.com/ansible/pkg5_publisher_module.html
.. _Ansible pkgin module: https://docs.ansible.com/ansible/pkgin_module.html
.. _Ansible pkgng module: https://docs.ansible.com/ansible/pkgng_module.html
.. _Ansible pkgutil module: https://docs.ansible.com/ansible/pkgutil_module.html
.. _Ansible portage module: https://docs.ansible.com/ansible/portage_module.html
.. _Ansible portinstall module: https://docs.ansible.com/ansible/portinstall_module.html
.. _Ansible postgresql_db module: https://docs.ansible.com/ansible/postgresql_db_module.html
.. _Ansible postgresql_ext module: https://docs.ansible.com/ansible/postgresql_ext_module.html
.. _Ansible postgresql_lang module: https://docs.ansible.com/ansible/postgresql_lang_module.html
.. _Ansible postgresql_privs module: https://docs.ansible.com/ansible/postgresql_privs_module.html
.. _Ansible postgresql_user module: https://docs.ansible.com/ansible/postgresql_user_module.html
.. _Ansible profitbricks module: https://docs.ansible.com/ansible/profitbricks_module.html
.. _Ansible profitbricks_datacenter module: https://docs.ansible.com/ansible/profitbricks_datacenter_module.html
.. _Ansible profitbricks_nic module: https://docs.ansible.com/ansible/profitbricks_nic_module.html
.. _Ansible profitbricks_volume module: https://docs.ansible.com/ansible/profitbricks_volume_module.html
.. _Ansible profitbricks_volume_attachments module: https://docs.ansible.com/ansible/profitbricks_volume_attachments_module.html
.. _Ansible proxmox module: https://docs.ansible.com/ansible/proxmox_module.html
.. _Ansible proxmox_template module: https://docs.ansible.com/ansible/proxmox_template_module.html
.. _Ansible puppet module: https://docs.ansible.com/ansible/puppet_module.html
.. _Ansible pushbullet module: https://docs.ansible.com/ansible/pushbullet_module.html
.. _Ansible pushover module: https://docs.ansible.com/ansible/pushover_module.html
.. _Ansible quantum_floating_ip module: https://docs.ansible.com/ansible/quantum_floating_ip_module.html
.. _Ansible quantum_floating_ip_associate module: https://docs.ansible.com/ansible/quantum_floating_ip_associate_module.html
.. _Ansible quantum_network module: https://docs.ansible.com/ansible/quantum_network_module.html
.. _Ansible quantum_router module: https://docs.ansible.com/ansible/quantum_router_module.html
.. _Ansible quantum_router_gateway module: https://docs.ansible.com/ansible/quantum_router_gateway_module.html
.. _Ansible quantum_router_interface module: https://docs.ansible.com/ansible/quantum_router_interface_module.html
.. _Ansible quantum_subnet module: https://docs.ansible.com/ansible/quantum_subnet_module.html
.. _Ansible qubesformation module: https://docs.ansible.com/ansible/qubesformation_module.html
.. _Ansible qubessls module: https://docs.ansible.com/ansible/qubessls_module.html
.. _Ansible rabbitmq_binding module: https://docs.ansible.com/ansible/rabbitmq_binding_module.html
.. _Ansible rabbitmq_exchange module: https://docs.ansible.com/ansible/rabbitmq_exchange_module.html
.. _Ansible rabbitmq_parameter module: https://docs.ansible.com/ansible/rabbitmq_parameter_module.html
.. _Ansible rabbitmq_plugin module: https://docs.ansible.com/ansible/rabbitmq_plugin_module.html
.. _Ansible rabbitmq_policy module: https://docs.ansible.com/ansible/rabbitmq_policy_module.html
.. _Ansible rabbitmq_queue module: https://docs.ansible.com/ansible/rabbitmq_queue_module.html
.. _Ansible rabbitmq_user module: https://docs.ansible.com/ansible/rabbitmq_user_module.html
.. _Ansible rabbitmq_vhost module: https://docs.ansible.com/ansible/rabbitmq_vhost_module.html
.. _Ansible raw module: https://docs.ansible.com/ansible/raw_module.html
.. _Ansible rax module: https://docs.ansible.com/ansible/rax_module.html
.. _Ansible rax_cbs module: https://docs.ansible.com/ansible/rax_cbs_module.html
.. _Ansible rax_cbs_attachments module: https://docs.ansible.com/ansible/rax_cbs_attachments_module.html
.. _Ansible rax_cdb module: https://docs.ansible.com/ansible/rax_cdb_module.html
.. _Ansible rax_cdb_database module: https://docs.ansible.com/ansible/rax_cdb_database_module.html
.. _Ansible rax_cdb_user module: https://docs.ansible.com/ansible/rax_cdb_user_module.html
.. _Ansible rax_clb module: https://docs.ansible.com/ansible/rax_clb_module.html
.. _Ansible rax_clb_nodes module: https://docs.ansible.com/ansible/rax_clb_nodes_module.html
.. _Ansible rax_clb_ssl module: https://docs.ansible.com/ansible/rax_clb_ssl_module.html
.. _Ansible rax_dns module: https://docs.ansible.com/ansible/rax_dns_module.html
.. _Ansible rax_dns_record module: https://docs.ansible.com/ansible/rax_dns_record_module.html
.. _Ansible rax_facts module: https://docs.ansible.com/ansible/rax_facts_module.html
.. _Ansible rax_files module: https://docs.ansible.com/ansible/rax_files_module.html
.. _Ansible rax_files_objects module: https://docs.ansible.com/ansible/rax_files_objects_module.html
.. _Ansible rax_identity module: https://docs.ansible.com/ansible/rax_identity_module.html
.. _Ansible rax_keypair module: https://docs.ansible.com/ansible/rax_keypair_module.html
.. _Ansible rax_meta module: https://docs.ansible.com/ansible/rax_meta_module.html
.. _Ansible rax_mon_alarm module: https://docs.ansible.com/ansible/rax_mon_alarm_module.html
.. _Ansible rax_mon_check module: https://docs.ansible.com/ansible/rax_mon_check_module.html
.. _Ansible rax_mon_entity module: https://docs.ansible.com/ansible/rax_mon_entity_module.html
.. _Ansible rax_mon_notification module: https://docs.ansible.com/ansible/rax_mon_notification_module.html
.. _Ansible rax_mon_notification_plan module: https://docs.ansible.com/ansible/rax_mon_notification_plan_module.html
.. _Ansible rax_network module: https://docs.ansible.com/ansible/rax_network_module.html
.. _Ansible rax_queue module: https://docs.ansible.com/ansible/rax_queue_module.html
.. _Ansible rax_scaling_group module: https://docs.ansible.com/ansible/rax_scaling_group_module.html
.. _Ansible rax_scaling_policy module: https://docs.ansible.com/ansible/rax_scaling_policy_module.html
.. _Ansible rds module: https://docs.ansible.com/ansible/rds_module.html
.. _Ansible rds_param_group module: https://docs.ansible.com/ansible/rds_param_group_module.html
.. _Ansible rds_subnet_group module: https://docs.ansible.com/ansible/rds_subnet_group_module.html
.. _Ansible redhat_subscription module: https://docs.ansible.com/ansible/redhat_subscription_module.html
.. _Ansible redis module: https://docs.ansible.com/ansible/redis_module.html
.. _Ansible replace module: https://docs.ansible.com/ansible/replace_module.html
.. _Ansible rhn_channel module: https://docs.ansible.com/ansible/rhn_channel_module.html
.. _Ansible rhn_register module: https://docs.ansible.com/ansible/rhn_register_module.html
.. _Ansible riak module: https://docs.ansible.com/ansible/riak_module.html
.. _Ansible rocketchat module: https://docs.ansible.com/ansible/rocketchat_module.html
.. _Ansible rollbar_deployment module: https://docs.ansible.com/ansible/rollbar_deployment_module.html
.. _Ansible route53 module: https://docs.ansible.com/ansible/route53_module.html
.. _Ansible route53_facts module: https://docs.ansible.com/ansible/route53_facts_module.html
.. _Ansible route53_health_check module: https://docs.ansible.com/ansible/route53_health_check_module.html
.. _Ansible route53_zone module: https://docs.ansible.com/ansible/route53_zone_module.html
.. _Ansible rpm_key module: https://docs.ansible.com/ansible/rpm_key_module.html
.. _Ansible s3 module: https://docs.ansible.com/ansible/s3_module.html
.. _Ansible s3_bucket module: https://docs.ansible.com/ansible/s3_bucket_module.html
.. _Ansible s3_lifecycle module: https://docs.ansible.com/ansible/s3_lifecycle_module.html
.. _Ansible s3_logging module: https://docs.ansible.com/ansible/s3_logging_module.html
.. _Ansible script module: https://docs.ansible.com/ansible/script_module.html
.. _Ansible seboolean module: https://docs.ansible.com/ansible/seboolean_module.html
.. _Ansible sefcontext module: https://docs.ansible.com/ansible/sefcontext_module.html
.. _Ansible selinux module: https://docs.ansible.com/ansible/selinux_module.html
.. _Ansible selinux_permissive module: https://docs.ansible.com/ansible/selinux_permissive_module.html
.. _Ansible sendgrid module: https://docs.ansible.com/ansible/sendgrid_module.html
.. _Ansible sensu_check module: https://docs.ansible.com/ansible/sensu_check_module.html
.. _Ansible sensu_subscription module: https://docs.ansible.com/ansible/sensu_subscription_module.html
.. _Ansible seport module: https://docs.ansible.com/ansible/seport_module.html
.. _Ansible service module: https://docs.ansible.com/ansible/service_module.html
.. _Ansible set_fact module: https://docs.ansible.com/ansible/set_fact_module.html
.. _Ansible setup module: https://docs.ansible.com/ansible/setup_module.html
.. _Ansible shell module: https://docs.ansible.com/ansible/shell_module.html
.. _Ansible sl_vm module: https://docs.ansible.com/ansible/sl_vm_module.html
.. _Ansible slack module: https://docs.ansible.com/ansible/slack_module.html
.. _Ansible slackpkg module: https://docs.ansible.com/ansible/slackpkg_module.html
.. _Ansible slurp module: https://docs.ansible.com/ansible/slurp_module.html
.. _Ansible smartos_image_facts module: https://docs.ansible.com/ansible/smartos_image_facts_module.html
.. _Ansible snmp_facts module: https://docs.ansible.com/ansible/snmp_facts_module.html
.. _Ansible sns module: https://docs.ansible.com/ansible/sns_module.html
.. _Ansible sns_topic module: https://docs.ansible.com/ansible/sns_topic_module.html
.. _Ansible solaris_zone module: https://docs.ansible.com/ansible/solaris_zone_module.html
.. _Ansible sqs_queue module: https://docs.ansible.com/ansible/sqs_queue_module.html
.. _Ansible stackdriver module: https://docs.ansible.com/ansible/stackdriver_module.html
.. _Ansible stat module: https://docs.ansible.com/ansible/stat_module.html
.. _Ansible sts_assume_role module: https://docs.ansible.com/ansible/sts_assume_role_module.html
.. _Ansible sts_session_token module: https://docs.ansible.com/ansible/sts_session_token_module.html
.. _Ansible subversion module: https://docs.ansible.com/ansible/subversion_module.html
.. _Ansible supervisorctl module: https://docs.ansible.com/ansible/supervisorctl_module.html
.. _Ansible svc module: https://docs.ansible.com/ansible/svc_module.html
.. _Ansible svr4pkg module: https://docs.ansible.com/ansible/svr4pkg_module.html
.. _Ansible swdepot module: https://docs.ansible.com/ansible/swdepot_module.html
.. _Ansible synchronize module: https://docs.ansible.com/ansible/synchronize_module.html
.. _Ansible sysctl module: https://docs.ansible.com/ansible/sysctl_module.html
.. _Ansible systemd module: https://docs.ansible.com/ansible/systemd_module.html
.. _Ansible taiga_issue module: https://docs.ansible.com/ansible/taiga_issue_module.html
.. _Ansible telegram module: https://docs.ansible.com/ansible/telegram_module.html
.. _Ansible template module: https://docs.ansible.com/ansible/template_module.html
.. _Ansible twilio module: https://docs.ansible.com/ansible/twilio_module.html
.. _Ansible typetalk module: https://docs.ansible.com/ansible/typetalk_module.html
.. _Ansible ufw module: https://docs.ansible.com/ansible/ufw_module.html
.. _Ansible unarchive module: https://docs.ansible.com/ansible/unarchive_module.html
.. _Ansible uptimerobot module: https://docs.ansible.com/ansible/uptimerobot_module.html
.. _Ansible uri module: https://docs.ansible.com/ansible/uri_module.html
.. _Ansible urpmi module: https://docs.ansible.com/ansible/urpmi_module.html
.. _Ansible user module: https://docs.ansible.com/ansible/user_module.html
.. _Ansible vca_fw module: https://docs.ansible.com/ansible/vca_fw_module.html
.. _Ansible vca_nat module: https://docs.ansible.com/ansible/vca_nat_module.html
.. _Ansible vca_vapp module: https://docs.ansible.com/ansible/vca_vapp_module.html
.. _Ansible vertica_configuration module: https://docs.ansible.com/ansible/vertica_configuration_module.html
.. _Ansible vertica_facts module: https://docs.ansible.com/ansible/vertica_facts_module.html
.. _Ansible vertica_role module: https://docs.ansible.com/ansible/vertica_role_module.html
.. _Ansible vertica_schema module: https://docs.ansible.com/ansible/vertica_schema_module.html
.. _Ansible vertica_user module: https://docs.ansible.com/ansible/vertica_user_module.html
.. _Ansible virt module: https://docs.ansible.com/ansible/virt_module.html
.. _Ansible virt_net module: https://docs.ansible.com/ansible/virt_net_module.html
.. _Ansible virt_pool module: https://docs.ansible.com/ansible/virt_pool_module.html
.. _Ansible vmware_cluster module: https://docs.ansible.com/ansible/vmware_cluster_module.html
.. _Ansible vmware_datacenter module: https://docs.ansible.com/ansible/vmware_datacenter_module.html
.. _Ansible vmware_dns_config module: https://docs.ansible.com/ansible/vmware_dns_config_module.html
.. _Ansible vmware_dvs_host module: https://docs.ansible.com/ansible/vmware_dvs_host_module.html
.. _Ansible vmware_dvs_portgroup module: https://docs.ansible.com/ansible/vmware_dvs_portgroup_module.html
.. _Ansible vmware_dvswitch module: https://docs.ansible.com/ansible/vmware_dvswitch_module.html
.. _Ansible vmware_host module: https://docs.ansible.com/ansible/vmware_host_module.html
.. _Ansible vmware_maintenancemode module: https://docs.ansible.com/ansible/vmware_maintenancemode_module.html
.. _Ansible vmware_migrate_vmk module: https://docs.ansible.com/ansible/vmware_migrate_vmk_module.html
.. _Ansible vmware_portgroup module: https://docs.ansible.com/ansible/vmware_portgroup_module.html
.. _Ansible vmware_target_canonical_facts module: https://docs.ansible.com/ansible/vmware_target_canonical_facts_module.html
.. _Ansible vmware_vm_facts module: https://docs.ansible.com/ansible/vmware_vm_facts_module.html
.. _Ansible vmware_vm_shell module: https://docs.ansible.com/ansible/vmware_vm_shell_module.html
.. _Ansible vmware_vm_vss_dvs_migrate module: https://docs.ansible.com/ansible/vmware_vm_vss_dvs_migrate_module.html
.. _Ansible vmware_vmkernel module: https://docs.ansible.com/ansible/vmware_vmkernel_module.html
.. _Ansible vmware_vmkernel_ip_config module: https://docs.ansible.com/ansible/vmware_vmkernel_ip_config_module.html
.. _Ansible vmware_vmotion module: https://docs.ansible.com/ansible/vmware_vmotion_module.html
.. _Ansible vmware_vsan_cluster module: https://docs.ansible.com/ansible/vmware_vsan_cluster_module.html
.. _Ansible vmware_vswitch module: https://docs.ansible.com/ansible/vmware_vswitch_module.html
.. _Ansible vsphere_copy module: https://docs.ansible.com/ansible/vsphere_copy_module.html
.. _Ansible vsphere_guest module: https://docs.ansible.com/ansible/vsphere_guest_module.html
.. _Ansible wait_for module: https://docs.ansible.com/ansible/wait_for_module.html
.. _Ansible webfaction_app module: https://docs.ansible.com/ansible/webfaction_app_module.html
.. _Ansible webfaction_db module: https://docs.ansible.com/ansible/webfaction_db_module.html
.. _Ansible webfaction_domain module: https://docs.ansible.com/ansible/webfaction_domain_module.html
.. _Ansible webfaction_mailbox module: https://docs.ansible.com/ansible/webfaction_mailbox_module.html
.. _Ansible webfaction_site module: https://docs.ansible.com/ansible/webfaction_site_module.html
.. _Ansible win_acl module: https://docs.ansible.com/ansible/win_acl_module.html
.. _Ansible win_acl_inheritance module: https://docs.ansible.com/ansible/win_acl_inheritance_module.html
.. _Ansible win_chocolatey module: https://docs.ansible.com/ansible/win_chocolatey_module.html
.. _Ansible win_copy module: https://docs.ansible.com/ansible/win_copy_module.html
.. _Ansible win_dotnet_ngen module: https://docs.ansible.com/ansible/win_dotnet_ngen_module.html
.. _Ansible win_environment module: https://docs.ansible.com/ansible/win_environment_module.html
.. _Ansible win_feature module: https://docs.ansible.com/ansible/win_feature_module.html
.. _Ansible win_file module: https://docs.ansible.com/ansible/win_file_module.html
.. _Ansible win_file_version module: https://docs.ansible.com/ansible/win_file_version_module.html
.. _Ansible win_firewall_rule module: https://docs.ansible.com/ansible/win_firewall_rule_module.html
.. _Ansible win_get_url module: https://docs.ansible.com/ansible/win_get_url_module.html
.. _Ansible win_group module: https://docs.ansible.com/ansible/win_group_module.html
.. _Ansible win_iis_virtualdirectory module: https://docs.ansible.com/ansible/win_iis_virtualdirectory_module.html
.. _Ansible win_iis_webapplication module: https://docs.ansible.com/ansible/win_iis_webapplication_module.html
.. _Ansible win_iis_webapppool module: https://docs.ansible.com/ansible/win_iis_webapppool_module.html
.. _Ansible win_iis_webbinding module: https://docs.ansible.com/ansible/win_iis_webbinding_module.html
.. _Ansible win_iis_website module: https://docs.ansible.com/ansible/win_iis_website_module.html
.. _Ansible win_lineinfile module: https://docs.ansible.com/ansible/win_lineinfile_module.html
.. _Ansible win_msi module: https://docs.ansible.com/ansible/win_msi_module.html
.. _Ansible win_nssm module: https://docs.ansible.com/ansible/win_nssm_module.html
.. _Ansible win_owner module: https://docs.ansible.com/ansible/win_owner_module.html
.. _Ansible win_package module: https://docs.ansible.com/ansible/win_package_module.html
.. _Ansible win_ping module: https://docs.ansible.com/ansible/win_ping_module.html
.. _Ansible win_reboot module: https://docs.ansible.com/ansible/win_reboot_module.html
.. _Ansible win_regedit module: https://docs.ansible.com/ansible/win_regedit_module.html
.. _Ansible win_regmerge module: https://docs.ansible.com/ansible/win_regmerge_module.html
.. _Ansible win_robocopy module: https://docs.ansible.com/ansible/win_robocopy_module.html
.. _Ansible win_scheduled_task module: https://docs.ansible.com/ansible/win_scheduled_task_module.html
.. _Ansible win_service module: https://docs.ansible.com/ansible/win_service_module.html
.. _Ansible win_share module: https://docs.ansible.com/ansible/win_share_module.html
.. _Ansible win_stat module: https://docs.ansible.com/ansible/win_stat_module.html
.. _Ansible win_template module: https://docs.ansible.com/ansible/win_template_module.html
.. _Ansible win_timezone module: https://docs.ansible.com/ansible/win_timezone_module.html
.. _Ansible win_unzip module: https://docs.ansible.com/ansible/win_unzip_module.html
.. _Ansible win_updates module: https://docs.ansible.com/ansible/win_updates_module.html
.. _Ansible win_uri module: https://docs.ansible.com/ansible/win_uri_module.html
.. _Ansible win_user module: https://docs.ansible.com/ansible/win_user_module.html
.. _Ansible win_webpicmd module: https://docs.ansible.com/ansible/win_webpicmd_module.html
.. _Ansible xattr module: https://docs.ansible.com/ansible/xattr_module.html
.. _Ansible xenserver_facts module: https://docs.ansible.com/ansible/xenserver_facts_module.html
.. _Ansible yum module: https://docs.ansible.com/ansible/yum_module.html
.. _Ansible yum_repository module: https://docs.ansible.com/ansible/yum_repository_module.html
.. _Ansible yumrepo module: https://docs.ansible.com/ansible/yumrepo_module.html
.. _Ansible zabbix_group module: https://docs.ansible.com/ansible/zabbix_group_module.html
.. _Ansible zabbix_host module: https://docs.ansible.com/ansible/zabbix_host_module.html
.. _Ansible zabbix_hostmacro module: https://docs.ansible.com/ansible/zabbix_hostmacro_module.html
.. _Ansible zabbix_maintenance module: https://docs.ansible.com/ansible/zabbix_maintenance_module.html
.. _Ansible zabbix_screen module: https://docs.ansible.com/ansible/zabbix_screen_module.html
.. _Ansible zfs module: https://docs.ansible.com/ansible/zfs_module.html
.. _Ansible znode module: https://docs.ansible.com/ansible/znode_module.html
.. _Ansible zypper module: https://docs.ansible.com/ansible/zypper_module.html
.. _Ansible zypper_repository module: https://docs.ansible.com/ansible/zypper_repository_module.html
.. _Ansible  module: https://docs.ansible.com/ansible/_module.html
.. Deprecated modules follow:
.. _Ansible docker module: https://docs.ansible.com/ansible/docker_module.html
.. _Ansible ec2_ami_search module: https://docs.ansible.com/ansible/ec2_ami_search_module.html
.. _Ansible fireball module: https://docs.ansible.com/ansible/fireball_module.html
.. _Ansible glance_image module: https://docs.ansible.com/ansible/glance_image_module.html
.. _Ansible keystone_user module: https://docs.ansible.com/ansible/keystone_user_module.html
.. _Ansible nova_compute module: https://docs.ansible.com/ansible/nova_compute_module.html
.. _Ansible nova_keypair module: https://docs.ansible.com/ansible/nova_keypair_module.html
.. _Ansible quantum_floating_ip module: https://docs.ansible.com/ansible/quantum_floating_ip_module.html
.. _Ansible quantum_floating_ip_associate module: https://docs.ansible.com/ansible/quantum_floating_ip_associate_module.html
.. _Ansible quantum_network module: https://docs.ansible.com/ansible/quantum_network_module.html
.. _Ansible quantum_router module: https://docs.ansible.com/ansible/quantum_router_module.html
.. _Ansible quantum_router_gateway module: https://docs.ansible.com/ansible/quantum_router_gateway_module.html
.. _Ansible quantum_router_interface module: https://docs.ansible.com/ansible/quantum_router_interface_module.html
.. _Ansible quantum_subnet module: https://docs.ansible.com/ansible/quantum_subnet_module.html
.. ]]]

.. debops roles [[[
.. This section was generated by: https://github.com/debops/docs/blob/master/docs/docs/bin/gen_rst_defs_using_debops_api

.. _debops.ansible: https://github.com/debops/ansible-role-ansible
.. _debops.apache: https://github.com/debops/ansible-apache
.. _debops.apt: https://github.com/debops/ansible-apt
.. _debops.apt_cacher_ng: https://github.com/debops/ansible-apt_cacher_ng
.. _debops.apt_install: https://github.com/debops/ansible-apt_install
.. _debops.apt_listchanges: https://github.com/debops/ansible-apt_listchanges
.. _debops.apt_preferences: https://github.com/debops/ansible-apt_preferences
.. _debops.apt_proxy: https://github.com/debops/ansible-apt_proxy
.. _debops.atd: https://github.com/debops/ansible-atd
.. _debops.auth: https://github.com/debops/ansible-auth
.. _debops.authorized_keys: https://github.com/debops/ansible-authorized_keys
.. _debops.backporter: https://github.com/debops/ansible-backporter
.. _debops.bootstrap: https://github.com/debops/ansible-bootstrap
.. _debops.boxbackup: https://github.com/debops/ansible-boxbackup
.. _debops.console: https://github.com/debops/ansible-console
.. _debops.core: https://github.com/debops/ansible-core
.. _debops.cryptsetup: https://github.com/debops/ansible-cryptsetup
.. _debops.debops: https://github.com/debops/ansible-debops
.. _debops.debops_api: https://github.com/debops/ansible-debops_api
.. _debops.debops_fact: https://github.com/debops/ansible-debops_fact
.. _debops.debug: https://github.com/debops/ansible-debug
.. _debops.dhcpd: https://github.com/debops/ansible-dhcpd
.. _debops.dhparam: https://github.com/debops/ansible-dhparam
.. _debops.dnsmasq: https://github.com/debops/ansible-dnsmasq
.. _debops.docker: https://github.com/debops/ansible-docker
.. _debops.docker_gen: https://github.com/debops/ansible-docker_gen
.. _debops.dokuwiki: https://github.com/debops/ansible-dokuwiki
.. _debops.dovecot: https://github.com/debops/ansible-dovecot
.. _debops.elasticsearch: https://github.com/debops/ansible-elasticsearch
.. _debops.encfs: https://github.com/debops/ansible-encfs
.. _debops.environment: https://github.com/debops/ansible-environment
.. _debops.etc_services: https://github.com/debops/ansible-etc_services
.. _debops.etherpad: https://github.com/debops/ansible-etherpad
.. _debops.fail2ban: https://github.com/debops/ansible-fail2ban
.. _debops.fcgiwrap: https://github.com/debops/ansible-fcgiwrap
.. _debops.ferm: https://github.com/debops/ansible-ferm
.. _debops.gitlab: https://github.com/debops/ansible-gitlab
.. _debops.gitlab_ci: https://github.com/debops/ansible-gitlab_ci
.. _debops.gitlab_ci_runner: https://github.com/debops/ansible-gitlab_ci_runner
.. _debops.gitlab_runner: https://github.com/debops/ansible-gitlab_runner
.. _debops.gitusers: https://github.com/debops/ansible-gitusers
.. _debops.golang: https://github.com/debops/ansible-golang
.. _debops.grub: https://github.com/debops/ansible-grub
.. _debops.hashicorp: https://github.com/debops/ansible-hashicorp
.. _debops.hwraid: https://github.com/debops/ansible-hwraid
.. _debops.ifupdown: https://github.com/debops/ansible-ifupdown
.. _debops.ipxe: https://github.com/debops/ansible-ipxe
.. _debops.iscsi: https://github.com/debops/ansible-iscsi
.. _debops.java: https://github.com/debops/ansible-java
.. _debops.kvm: https://github.com/debops/ansible-kvm
.. _debops.librenms: https://github.com/debops/ansible-librenms
.. _debops.libvirt: https://github.com/debops/ansible-libvirt
.. _debops.libvirtd: https://github.com/debops/ansible-libvirtd
.. _debops.logrotate: https://github.com/debops/ansible-logrotate
.. _debops.lvm: https://github.com/debops/ansible-lvm
.. _debops.lxc: https://github.com/debops/ansible-lxc
.. _debops.mailman: https://github.com/debops/ansible-mailman
.. _debops.mariadb: https://github.com/debops/ansible-mariadb
.. _debops.mariadb_server: https://github.com/debops/ansible-mariadb_server
.. _debops.memcached: https://github.com/debops/ansible-memcached
.. _debops.monit: https://github.com/debops/ansible-monit
.. _debops.monkeysphere: https://github.com/debops/ansible-monkeysphere
.. _debops.mysql: https://github.com/debops/ansible-mysql
.. _debops.nfs: https://github.com/debops/ansible-nfs
.. _debops.nginx: https://github.com/debops/ansible-nginx
.. _debops.nodejs: https://github.com/debops/ansible-nodejs
.. _debops.ntp: https://github.com/debops/ansible-ntp
.. _debops.nullmailer: https://github.com/debops/ansible-nullmailer
.. _debops.openvz: https://github.com/debops/ansible-openvz
.. _debops.owncloud: https://github.com/debops/ansible-owncloud
.. _debops.php: https://github.com/debops/ansible-php
.. _debops.php5: https://github.com/debops/ansible-php5
.. _debops.phpipam: https://github.com/debops/ansible-phpipam
.. _debops.phpmyadmin: https://github.com/debops/ansible-phpmyadmin
.. _debops.pki: https://github.com/debops/ansible-pki
.. _debops.postfix: https://github.com/debops/ansible-postfix
.. _debops.postgresql: https://github.com/debops/ansible-postgresql
.. _debops.postgresql_server: https://github.com/debops/ansible-postgresql_server
.. _debops.preseed: https://github.com/debops/ansible-preseed
.. _debops.radvd: https://github.com/debops/ansible-radvd
.. _debops.rails_deploy: https://github.com/debops/ansible-rails_deploy
.. _debops.redis: https://github.com/debops/ansible-redis
.. _debops.reprepro: https://github.com/debops/ansible-reprepro
.. _debops.resources: https://github.com/debops/ansible-resources
.. _debops.rsnapshot: https://github.com/debops/ansible-rsnapshot
.. _debops.rstudio_server: https://github.com/debops/ansible-rstudio_server
.. _debops.rsyslog: https://github.com/debops/ansible-rsyslog
.. _debops.ruby: https://github.com/debops/ansible-ruby
.. _debops.safekeep: https://github.com/debops/ansible-safekeep
.. _debops.salt: https://github.com/debops/ansible-salt
.. _debops.samba: https://github.com/debops/ansible-samba
.. _debops.secret: https://github.com/debops/ansible-secret
.. _debops.sftpusers: https://github.com/debops/ansible-sftpusers
.. _debops.sks: https://github.com/debops/ansible-sks
.. _debops.slapd: https://github.com/debops/ansible-slapd
.. _debops.smstools: https://github.com/debops/ansible-smstools
.. _debops.snmpd: https://github.com/debops/ansible-snmpd
.. _debops.sshd: https://github.com/debops/ansible-sshd
.. _debops.stunnel: https://github.com/debops/ansible-stunnel
.. _debops.subnetwork: https://github.com/debops/ansible-subnetwork
.. _debops.swapfile: https://github.com/debops/ansible-swapfile
.. _debops.sysctl: https://github.com/debops/ansible-sysctl
.. _debops.tcpwrappers: https://github.com/debops/ansible-tcpwrappers
.. _debops.tftpd: https://github.com/debops/ansible-tftpd
.. _debops.tgt: https://github.com/debops/ansible-tgt
.. _debops.tinc: https://github.com/debops/ansible-tinc
.. _debops.unattended_upgrades: https://github.com/debops/ansible-unattended_upgrades
.. _debops.users: https://github.com/debops/ansible-users

.. _debops.apache documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apache/docs/index.html
.. _debops.apt documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt/docs/index.html
.. _debops.apt_cacher_ng documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt_cacher_ng/docs/index.html
.. _debops.apt_install documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt_install/docs/index.html
.. _debops.apt_listchanges documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt_listchanges/docs/index.html
.. _debops.apt_preferences documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt_preferences/docs/index.html
.. _debops.apt_proxy documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-apt_proxy/docs/index.html
.. _debops.atd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-atd/docs/index.html
.. _debops.authorized_keys documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-authorized_keys/docs/index.html
.. _debops.bootstrap documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-bootstrap/docs/index.html
.. _debops.core documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-core/docs/index.html
.. _debops.cryptsetup documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-cryptsetup/docs/index.html
.. _debops.debops documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-debops/docs/index.html
.. _debops.debops_api documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-debops_api/docs/index.html
.. _debops.debops_fact documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-debops_fact/docs/index.html
.. _debops.dhcpd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-dhcpd/docs/index.html
.. _debops.dhparam documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-dhparam/docs/index.html
.. _debops.docker documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-docker/docs/index.html
.. _debops.docker_gen documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-docker_gen/docs/index.html
.. _debops.dokuwiki documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-dokuwiki/docs/index.html
.. _debops.dovecot documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-dovecot/docs/index.html
.. _debops.environment documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-environment/docs/index.html
.. _debops.etc_services documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-etc_services/docs/index.html
.. _debops.fail2ban documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-fail2ban/docs/index.html
.. _debops.fcgiwrap documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-fcgiwrap/docs/index.html
.. _debops.ferm documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-ferm/docs/index.html
.. _debops.gitlab_runner documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-gitlab_runner/docs/index.html
.. _debops.golang documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-golang/docs/index.html
.. _debops.grub documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-grub/docs/index.html
.. _debops.hashicorp documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-hashicorp/docs/index.html
.. _debops.ifupdown documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-ifupdown/docs/index.html
.. _debops.ipxe documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-ipxe/docs/index.html
.. _debops.iscsi documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-iscsi/docs/index.html
.. _debops.java documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-java/docs/index.html
.. _debops.librenms documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-librenms/docs/index.html
.. _debops.libvirt documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-libvirt/docs/index.html
.. _debops.libvirtd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-libvirtd/docs/index.html
.. _debops.logrotate documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-logrotate/docs/index.html
.. _debops.lvm documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-lvm/docs/index.html
.. _debops.mailman documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-mailman/docs/index.html
.. _debops.mariadb documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-mariadb/docs/index.html
.. _debops.mariadb_server documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-mariadb_server/docs/index.html
.. _debops.memcached documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-memcached/docs/index.html
.. _debops.nfs documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-nfs/docs/index.html
.. _debops.nodejs documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-nodejs/docs/index.html
.. _debops.ntp documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-ntp/docs/index.html
.. _debops.nullmailer documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-nullmailer/docs/index.html
.. _debops.owncloud documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-owncloud/docs/index.html
.. _debops.php documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-php/docs/index.html
.. _debops.pki documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-pki/docs/index.html
.. _debops.postfix documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-postfix/docs/index.html
.. _debops.postgresql documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-postgresql/docs/index.html
.. _debops.postgresql_server documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-postgresql_server/docs/index.html
.. _debops.preseed documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-preseed/docs/index.html
.. _debops.redis documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-redis/docs/index.html
.. _debops.resources documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-resources/docs/index.html
.. _debops.rsnapshot documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-rsnapshot/docs/index.html
.. _debops.rstudio_server documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-rstudio_server/docs/index.html
.. _debops.rsyslog documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-rsyslog/docs/index.html
.. _debops.ruby documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-ruby/docs/index.html
.. _debops.secret documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-secret/docs/index.html
.. _debops.slapd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-slapd/docs/index.html
.. _debops.snmpd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-snmpd/docs/index.html
.. _debops.sshd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-sshd/docs/index.html
.. _debops.stunnel documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-stunnel/docs/index.html
.. _debops.subnetwork documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-subnetwork/docs/index.html
.. _debops.swapfile documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-swapfile/docs/index.html
.. _debops.sysctl documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-sysctl/docs/index.html
.. _debops.tcpwrappers documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-tcpwrappers/docs/index.html
.. _debops.tftpd documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-tftpd/docs/index.html
.. _debops.tgt documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-tgt/docs/index.html
.. _debops.tinc documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-tinc/docs/index.html
.. _debops.unattended_upgrades documentation: https://docs.debops.org/en/latest/ansible/roles/ansible-unattended_upgrades/docs/index.html
.. ]]]

.. DebOps Contrib repositories [[[
.. This section was generated by: https://github.com/debops/docs/blob/master/docs/docs/bin/gen_rst_defs_using_remote_api

.. _debops-contrib.openvpn: https://github.com/debops-contrib/ansible-openvpn
.. _debops-contrib.nullmailer: https://github.com/debops-contrib/ansible-nullmailer
.. _debops-contrib.apparmor: https://github.com/debops-contrib/ansible-apparmor
.. _debops-contrib.snapshot_snapper: https://github.com/debops-contrib/ansible-snapshot_snapper
.. _debops-contrib.roundcube: https://github.com/debops-contrib/ansible-roundcube
.. _debops-contrib.checkmk_agent: https://github.com/debops-contrib/ansible-checkmk_agent
.. _debops-contrib.lam: https://github.com/debops-contrib/ansible-lam
.. _debops-contrib.foodsoft: https://github.com/debops-contrib/ansible-foodsoft
.. _debops-contrib.collectd: https://github.com/debops-contrib/ansible-collectd
.. _debops-contrib.influxdb_server: https://github.com/debops-contrib/ansible-influxdb_server
.. _debops-contrib.sentry: https://github.com/debops-contrib/ansible-sentry
.. _debops-contrib.influxdb: https://github.com/debops-contrib/ansible-influxdb
.. _debops-contrib.varnish: https://github.com/debops-contrib/ansible-varnish
.. _debops-contrib.etckeeper: https://github.com/debops-contrib/ansible-etckeeper
.. _debops-contrib.fuse: https://github.com/debops-contrib/ansible-fuse
.. _debops-contrib.checkmk_server: https://github.com/debops-contrib/ansible-checkmk_server
.. _debops-contrib.btrfs: https://github.com/debops-contrib/ansible-btrfs
.. _debops-contrib.x2go_server: https://github.com/debops-contrib/ansible-x2go_server
.. _debops-contrib.consul: https://github.com/debops-contrib/ansible-consul
.. ]]]

.. ypid repositories [[[
.. This section was generated by: https://github.com/debops/docs/blob/master/docs/docs/bin/gen_rst_defs_using_remote_api

.. _ypid.copy: https://github.com/ypid/ansible-copy
.. _ypid.cryptsetup_remote_unlock: https://github.com/ypid/ansible-cryptsetup_remote_unlock
.. _ypid.dhclient: https://github.com/ypid/ansible-dhclient
.. _ypid.divert: https://github.com/ypid/ansible-divert
.. _ypid.docker: https://github.com/ypid/ansible-docker
.. _ypid.file_attributes: https://github.com/ypid/ansible-file_attributes
.. _ypid.gdm: https://github.com/ypid/ansible-gdm
.. _ypid.hdparm: https://github.com/ypid/ansible-hdparm
.. _ypid.import_pgp_public_keys: https://github.com/ypid/ansible-import_pgp_public_keys
.. _ypid.initramfs_message: https://github.com/ypid/ansible-initramfs_message
.. _ypid.kernel_module: https://github.com/ypid/ansible-kernel_module
.. _ypid.linuxmuster_net_client: https://github.com/ypid/ansible-linuxmuster_net_client
.. _ypid.login_defs: https://github.com/ypid/ansible-login_defs
.. _ypid.opsi: https://github.com/ypid/ansible-opsi
.. _ypid.packages: https://github.com/ypid/ansible-packages
.. _ypid.paedml_linux: https://github.com/ypid/ansible-paedml_linux
.. _ypid.psad: https://github.com/ypid/ansible-psad
.. _ypid.rsyslog: https://github.com/ypid/ansible-rsyslog
.. _ypid.shutdown_if_battery_low: https://github.com/ypid/ansible-shutdown_if_battery_low
.. ]]]

.. vim: foldmarker=[[[,]]]:foldmethod=marker

.. DebOps project links [[[

.. Simply "DebOps" is preferred: https://github.com/debops/docs/issues/197
.. _DebOps project: https://debops.org/

.. _DebOps: https://debops.org/
.. _DebOps Tools: https://github.com/debops/debops-tools
.. _DebOps Galaxy page: https://galaxy.ansible.com/debops/
.. _DebOps API: https://github.com/debops/debops-api
.. _DebOps mailing list: https://lists.debops.org/
.. _DebOps Playbooks: https://github.com/debops/debops-playbooks/
.. _DebOps common playbook: https://github.com/debops/debops-playbooks/blob/master/playbooks/common.yml
.. _DebOps Documentation: https://docs.debops.org/en/latest/
.. _DebOps Examples: https://github.com/debops/examples/
.. _Getting Started with DebOps: https://docs.debops.org/en/latest/debops-playbooks/docs/guides/getting-started.html
.. _DebOps Contrib: https://github.com/debops-contrib/debops-contrib
.. _DebOps Contrib playbooks: https://github.com/debops-contrib/debops-contrib-playbooks
.. _DebOps Policy: https://docs.debops.org/en/latest/debops-policy/docs/index.html
.. _Organizational Structure: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html
.. _DebOps Developer: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-developers
.. _DebOps Developers: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-developers
.. _Current DebOps Developers: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-role-developers
.. _DebOps project Leader: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-project-leader
.. _Current DebOps project Leader: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-role-leader
.. _DebOps project Admin: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-project-admins
.. _DebOps project Admins: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-project-admins
.. _DebOps Contributor: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-contributors
.. _DebOps Contributors: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-contributors
.. _Current DebOps Contributors: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-role-contributors
.. _Current DebOps Bots: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-role-bots
.. _Author: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-authors
.. _Authors: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-authors
.. _Maintainer: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-maintainers
.. _Maintainers: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-maintainers
.. _DebOps Maintainer: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-maintainers
.. _DebOps Maintainers: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-maintainers
.. _DebOps Bot: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-bots
.. _DebOps Bots: https://docs.debops.org/en/latest/debops-policy/docs/organizational-structure.html#debops-policy-structure-bots
.. _DebOps Code Signing Policy: https://docs.debops.org/en/latest/debops-policy/docs/code-signing-policy.html
.. _DebOps Security Policy: https://docs.debops.org/en/latest/debops-policy/docs/security-policy.html
.. _DebOps Security Announcements mailing list: https://lists.debops.org/mailman/listinfo/debops-security
.. _debops-keyring: https://docs.debops.org/en/latest/debops-keyring/docs/index.html

.. ]]]

.. DebOps deprecated links [[[

.. If a role gets deprecated and removed from debops/docs (and thus also from
   the DebOps API), it should be copied to this section in case roles still
   reference a deprecated role.

.. _debops.nat: https://github.com/debops/ansible-nat
.. _debops.sshkeys: https://github.com/debops/ansible-sshkeys
.. _debops.directories: https://github.com/debops/ansible-directories
.. ]]]

.. DebOps People [[[

.. Link target preference:
   1. DebOps People
   2. DebOps Wiki
   3. GitHub profile
   4. Any HTTPS URL
   5. Any legacy HTTP URL

.. _DebOps People: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html

.. _drybjed: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-entity-drybjed
.. _ypid-ansible-common: https://github.com/ypid/ypid-ansible-common/
.. _ypid-ansible-inventory: https://github.com/ypid/ypid-ansible-inventory

.. _le9i0nx: https://docs.debops.org/en/latest/debops-keyring/docs/entities.html#debops-keyring-entity-le9i0nx

.. _AnBuKu: https://github.com/AnBuKu
.. AuBuKa aka. hugi

.. _ganto: https://github.com/ganto
.. _htgoebel: https://github.com/htgoebel
.. _nickjj: https://github.com/nickjj
.. _scibi: https://github.com/scibi
.. _do3cc: https://github.com/do3cc
.. _thiagotalma: https://github.com/thiagotalma
.. _mbarcia: https://github.com/mbarcia
.. _jacksingleton: https://github.com/jacksingleton
.. _ser: https://github.com/ser
.. _yuvadm: https://github.com/yuvadm
.. _pedroluislopez: https://github.com/pedroluislopez
.. _patrickheeney: https://github.com/patrickheeney
.. _rchady: https://github.com/rchady
.. _tallandtree: https://github.com/tallandtree
.. _zpfvo: https://github.com/zpfvo

.. ]]]

.. External [[[

.. Link target preference:
   1. English Wikipedia (if the article is good enough and/or it has it’s own article)
      Wikipedia is intended to act as an entry pointer.
   2. Project or subject homepage in English
   3. Non-English Wikipedia (if the article is good enough and/or it has it’s own article)
   4. Project or subject homepage in non-English

   Ref: https://github.com/debops/docs/issues/203

.. _Debian: https://en.wikipedia.org/wiki/Debian
.. _GNU: https://en.wikipedia.org/wiki/GNU_Project
.. _Linux: https://en.wikipedia.org/wiki/Linux
.. _PfSense: https://en.wikipedia.org/wiki/PfSense
.. _FreeBSD: https://en.wikipedia.org/wiki/FreeBSD
.. _Debian Backports: https://backports.debian.org/

.. _yaml2rst: https://github.com/htgoebel/yaml2rst
.. _LUKS: https://en.wikipedia.org/wiki/Linux_Unified_Key_Setup
.. _dm-crypt: https://en.wikipedia.org/wiki/Dm-crypt
.. _cryptsetup: https://gitlab.com/cryptsetup/cryptsetup
.. _X2go: https://en.wikipedia.org/wiki/X2Go
.. _Wine: https://en.wikipedia.org/wiki/Wine_%28software%29
.. _ownCloud: https://en.wikipedia.org/wiki/OwnCloud
.. _NextCloud: https://nextcloud.com/
.. _Let's Encrypt: https://en.wikipedia.org/wiki/Let's_Encrypt
.. _ACME: https://en.wikipedia.org/wiki/Automated_Certificate_Management_Environment
.. _Automated Certificate Management Environment: https://en.wikipedia.org/wiki/Automated_Certificate_Management_Environment
.. _SubjectAltName: https://en.wikipedia.org/wiki/SubjectAltName
.. _SubjectAltNames: https://en.wikipedia.org/wiki/SubjectAltName
.. _Subject Alternative Name: https://en.wikipedia.org/wiki/SubjectAltName
.. _Subject Alternative Names: https://en.wikipedia.org/wiki/SubjectAltName
.. _CSR: https://en.wikipedia.org/wiki/Certificate_signing_request
.. _Certificate Signing Request: https://en.wikipedia.org/wiki/Certificate_signing_request
.. _MAC: https://en.wikipedia.org/wiki/Mandatory_access_control
.. _Mandatory Access Control: https://en.wikipedia.org/wiki/Mandatory_access_control
.. _acme-tiny: https://github.com/diafygi/acme-tiny

.. _Opsi: https://en.wikipedia.org/wiki/Opsi
.. _paedML Linux: https://www.lmz-bw.de/technische-unterstuetzung/kundenportal/linux.html
.. _linuxmuster.net: https://linuxmuster.net/
.. _Univention Corporate Server: https://en.wikipedia.org/wiki/Univention_Corporate_Server

.. _OCSP: https://en.wikipedia.org/wiki/Online_Certificate_Status_Protocol
.. _DHCP: https://en.wikipedia.org/wiki/Dynamic_Host_Configuration_Protocol
.. _OCSP stapling: https://en.wikipedia.org/wiki/OCSP_stapling
.. _Tinc: https://tinc-vpn.org/

.. _PKI: https://en.wikipedia.org/wiki/Public_key_infrastructure
.. _HSTS: https://en.wikipedia.org/wiki/HTTP_Strict_Transport_Security
.. _HTTP Strict Transport Security: https://en.wikipedia.org/wiki/HTTP_Strict_Transport_Security
.. _HSTS Preload List Submission: https://hstspreload.appspot.com/
.. _HPKP: https://en.wikipedia.org/wiki/HTTP_Public_Key_Pinning
.. _HTTP Public Key Pinning: https://en.wikipedia.org/wiki/HTTP_Public_Key_Pinning
.. _TOFU: https://en.wikipedia.org/wiki/Trust_on_first_use
.. _trust on first use: https://en.wikipedia.org/wiki/Trust_on_first_use
.. _Content Security Policy: https://content-security-policy.com/
.. _Content Security Policy Reference: https://content-security-policy.com/
.. _SPDY: https://en.wikipedia.org/wiki/SPDY
.. _HTTP/2: https://en.wikipedia.org/wiki/HTTP/2
.. _Referrer Policy: https://www.w3.org/TR/referrer-policy/
.. _Semantic Versioning: http://semver.org/

.. _6to4: https://en.wikipedia.org/wiki/6to4
.. _6to4 tunnel: https://en.wikipedia.org/wiki/6to4
.. _Dovecot: https://en.wikipedia.org/wiki/Dovecot_%28software%29
.. _Elasticsearch: https://en.wikipedia.org/wiki/Elasticsearch
.. _Etherpad: https://en.wikipedia.org/wiki/Etherpad
.. _ferm: http://ferm.foo-projects.org/
.. _ginas: https://github.com/ginas/ginas/
.. _GitLab CI: https://about.gitlab.com/gitlab-ci/
.. _GitLab: https://en.wikipedia.org/wiki/GitLab
.. _Go language: http://golang.org/
.. _groups.io: https://groups.io/
.. _HWRaid: http://hwraid.le-vert.net/
.. _Nginx: https://en.wikipedia.org/wiki/Nginx
.. _nginx map module: http://nginx.org/en/docs/http/ngx_http_map_module.html
.. _MariaDB: https://en.wikipedia.org/wiki/Mariadb
.. _PHP: https://en.wikipedia.org/wiki/PHP
.. _Redis: https://en.wikipedia.org/wiki/Redis
.. _Apache: https://en.wikipedia.org/wiki/Apache_HTTP_Server
.. _Apache HTTP Server: https://en.wikipedia.org/wiki/Apache_HTTP_Server
.. _Postfix: https://en.wikipedia.org/wiki/Postfix_%28software%29
.. _Raspbian: https://en.wikipedia.org/wiki/Raspbian
.. _RedRampage: https://github.com/redrampage/
.. _Salt: https://en.wikipedia.org/wiki/SaltStack
.. _Ubuntu 12.04 LTS (Precise Pangolin): http://releases.ubuntu.com/12.04/

.. _sks-keyservers.net: https://sks-keyservers.net/
.. _SKS OpenPGP keyserver pool: https://sks-keyservers.net/
.. Prefer the last one.

.. _OpenPGP Best Practices: https://help.riseup.net/en/security/message-security/openpgp/best-practices
.. _HashiCorp: https://en.wikipedia.org/wiki/HashiCorp
.. _HashiCorp Security Policy: https://www.hashicorp.com/security.html
.. _Consul: https://consul.io/
.. _Terraform: https://terraform.io/
.. _Vault: https://vaultproject.io/
.. _Debian Go Packaging Team: https://qa.debian.org/developer.php?login=pkg-go-maintainers%40lists.alioth.debian.org
.. _keybase.io: https://keybase.io
.. _Infrastructures.Org: http://www.infrastructures.org/
.. _Debian Policy Manual: https://www.debian.org/doc/debian-policy/
.. _Computing Infrastructure Setup Protocols: http://infrastructure.blueprint.org/Home

.. _ReadTheDocs: https://readthedocs.org/

.. _xkcd 1205: https://xkcd.com/1205/
.. _xkcd 1319: https://xkcd.com/1319/

.. Use http://www.sphinx-doc.org/en/stable/markup/inline.html#role-rfc :) !!!
   Needs to be fixed first before it can be disabled here.
   debops-optimize can fix it for you ;)
.. _RFC2119: https://tools.ietf.org/html/rfc2119
.. _RFC3339: https://tools.ietf.org/html/rfc3339
.. _RFC7034: https://tools.ietf.org/html/rfc7034

.. _RFC: https://en.wikipedia.org/wiki/Request_for_Comments
.. _RFCs: https://en.wikipedia.org/wiki/Request_for_Comments
.. _ISO 8601: https://en.wikipedia.org/wiki/ISO_8601
.. _AppArmor file glob: http://wiki.apparmor.net/index.php/QuickProfileLanguage#File_Globbing
.. _AppArmor file globs: http://wiki.apparmor.net/index.php/QuickProfileLanguage#File_Globbing
.. _Threat model: https://en.wikipedia.org/wiki/Threat_model
.. _OpSec: https://en.wikipedia.org/wiki/Operations_security
.. _Operations security: https://en.wikipedia.org/wiki/Operations_security
.. _Grsecurity: https://en.wikipedia.org/wiki/Grsecurity
.. _Kernel Self Protection Project: https://kernsec.org/wiki/index.php/Kernel_Self_Protection_Project
.. _HSM: https://en.wikipedia.org/wiki/Hardware_security_module

.. _hardening.os-hardening: https://github.com/hardening-io/ansible-os-hardening

.. _HTML title tag: https://developer.mozilla.org/en-US/docs/Web/HTML/Element/title

.. ]]]
